<p align="center">
  <img src="docs/img/rugemmie.gif" />  
</p>
<p align="center">
<a href="https://temmies.readthedocs.io/en/latest/"><img alt="Read the Docs" src="https://img.shields.io/readthedocs/temmies"></a>
<img alt="GitHub" src="https://img.shields.io/github/license/Code-For-Groningen/temmies">
</p>

A python library which interacts with themis. Uses bs4. I'll try to end development on a somewhat working state. 

## Intended Features
* [x] Log in  
* [x] Submit
* [x] Bulk download of test cases and files
* [x] Submission status

## Docs
[here](http://temmies.rtfd.io/).

## Possible continuations
* Discord bot
* CLI program

## Thanks to
* [Glitchcat](https://glitchcat.github.io/themis-api/), cool docs bro.
* [Mo](https://github.com/Stylo2k), damn bruh you actually work for Themis